val debug : bool ref
(** Setting it [true] enables some printf debugs *)
  
val init : unit -> string * Ocamlfind.Package.t list * Opam.Switch.t
(** Initializaiton of OCamlFind and OPAM in one move.
    It checks the OCamlFind's stdlib directory is under OPAM's prefix.
    If not, it throws an exception.
*)

val associate :
  Ocamlfind.Analyzed_group.t list
  -> Opam.Package.t list
  -> (Opam.Package.t * (Ocamlfind.Analyzed_group.t * string list) list) list
     * (Ocamlfind.Analyzed_group.t * Opam.Package.t list) list
(** Analyze which OAM package provides which Ocamlfind packages. 

    The result consists of two parts:

    1. Which OAM package installs which OCamlFind packages.

       Each OCamlFind package group is associated with an evidence, a list of files 
       in OPAM build directory also found in the OCamlFind package installation.
 
    2. Which OCamlFind is installed by which OPAM package.

       If no OPAM packages is listed for an OCamlFind package group,
       it may be installed by OCaml compiler itself.
       Or, it may be not installed by OPAM at all.

       If more than two OPAM packages are listed for one OCamlFind package group,
       it is likely the analysis is ambiguous.
*)

val test : unit -> unit
(** Run some tests *)
