module CMIDigest : sig
  type t [@@deriving conv{ocaml}]
  (** This is OCaml module interface checksum. Not file content MD5 checksum. *)

  val of_cu	: Cmo_format.compilation_unit -> t
  val of_ui	: Cmx_format.unit_infos -> t
  val of_cmi	: Cmi_format.cmi_infos -> t

  val to_string : t -> string
end

val load : string -> [> `ByteExec
                     | `CMA  of Cmo_format.library
                     | `CMI  of Cmi_format.cmi_infos
                     | `CMO  of Cmo_format.compilation_unit
                     | `CMX  of Cmx_format.unit_infos
                     | `CMXA of Cmx_format.library_infos
                     | `CMXS ] option
(** Load a CM file *) 
                  
val cmi_md5 : Module_path.t -> (string * CMIDigest.t) option
(** For the given module path, returns its cmi file path
    and signature md5 checksum. *)

val cmi_without_value : string -> bool
(** [cmi_without_value cmipath] returns [true] if the cmi file contains no value
    components. If true, the file *may* be built from an mli only module *)

val find_cmi_file : string -> string option
(** [find_cmi_file "list"] finds "list.cmi" in the current [Config.load_path] *)

val get_compilation_units : string -> string list option
(** [get_compilation_units file] obtains the list of compilation units
    i.e. module names like "List" of the given .cmo/.cmx/.cma/.cmxa file
*)

val check_compilation_unit : string -> string -> string option
(** [check_compilation_unit dir uname] checks the cmi file of the unit [uname]
    in directory [dir]:  [check_compilation_unit dir "List"] tries to find
    [dir ^/ "list.cmi"].
*)


