(** OPAM tools 

    Note that these functions do not use OPAM API but results of 
    opam cli commands, so they may be inaccurate, and are fragile to 
    any change of opam command output.
*)

module Switch : sig
  type t = {
    switch : string;             (** switch: ex. ["system"], ["4.03.0"] *)
    prefix : string;             (** ex. ["~/.opam/<switch>"] *)
    build_dir : string;          (** ex. ["~/.opam/<switch>/build"] *)
    compiler_source_dir : string (** ex. ["~/.opam/<switch>/build/ocaml"] *)
  }

  val get : unit -> t
  (** Get the current OPAM switch by executing "opam switch" command *)
end
  
module Package : sig
  type t = {
    name    : string;
    version : string;
    desc    : string; (** short description of the package *)
    base    : bool;   (** [true] means it is a virtual base package, 
                          such as base-bigarray, base-bytes, base-unix. *)
    switch  : Switch.t; (** the switch *)
  } [@@deriving conv{ocaml}]

  val format : Format.formatter -> t -> unit

  val name_version : t -> string
  (** Returns [name.version] like ["cmdliner.0.9.8"] *)

  val build_dir : t -> string
  (** Returns the build directory of the package. The existence of the result
      is not assured. *)

  val opam_path : t -> string option
  (** Returns the directory which contains the [opam] and other package 
      description files. *)    
end

val package_dir_of
  : Switch.t
  -> string
  -> [> `OCamlFindLib of string list
     |  `OPAMBuild of string list ] option
(** Given the path of a build/library file, deduce its OPAM switch and 
    OPAM package/OCamlFind package respectively. 
*)

val get_installed : Switch.t -> Package.t list
(** Installed OPAM packages *)

val test : unit -> unit
(** Runs some tests *)
